@@ -1,31 +1,3 @@
-"""
-Serializable map of integers to bytes with near zero parsing.
-
-MapBuffer is designed to allow you to store dictionaries mapping 
-integers to binary buffers in a serialized format and then read 
-that back in and use it without requiring an expensive parse of 
-the entire dictionary. Instead, if you have a dictionary containing 
-thousands of keys, but only need a few items from it, you can 
-extract them rapidly.
-
-Simple Example:
-
-  from mapbuffer import MapBuffer
-
-  data = { 2848: b'abc', 12939: b'123' }
-  mb = MapBuffer(data)
-
-  with open("data.mb", "wb") as f:
-    f.write(mb.tobytes())
-
-  with open("data.mb", "rb") as f:
-    binary = f.read()
-
-  mb = MapBuffer(binary)
-  print(mb[2848]) # fast: almost zero parsing required
-
-  >>> b'abc'
-"""
 from .exceptions import ValidationError
 from .lib import nvl
 from . import compression
@@ -217,7 +189,7 @@ class MapBuffer:
     for i, label in zip(range(1, len(labels)), labels):
       index[i*2 + 1] = index[(i-1)*2 + 1] + len(bytes_data[labels[i-1]])
 
-    return header + index.tobytes() + data_region
+    return b"".join([ header, index.tobytes(), data_region ])
 
   def todict(self):
     return { label: val for label, val in self.items() }
